@@ -351,38 +351,9 @@ sub _FileDialog_button_Delete {
 	# opens file and populates GUI
 	$L_SU_href->{_flow_color} = $neutral_flow->get_flow_color();
 	$neutral_flow->set_hash_ref($L_SU_href);
-	
-	#				my $Flow_file_exists = $grey_flow->get_Flow_file_exists();
-	#
-	#				if (   $Flow_file_exists
-	#					)
-	#				{
-	#
-	#					$color_listbox->set_flow_listbox_color($color);
-	#
-	#				}
-
-	# Flow when program opens a (pre-existing) user-built perl flow
-	# user flows can be already in progress
-	# user flows may not be already in progress
-	# but no color or colored listbox is active,
-
-	#			$color_listbox->set_flow_listbox_color( _get_flow_color() );
-	#			$L_SU_gui->{_occupied_listbox_aref} =
-	#			  $color_listbox->get_flow_listbox_occupancy_aref();
-	#			$L_SU_gui->{_vacant_listbox_aref} =
-	#			  $color_listbox->get_flow_listbox_vacancy_aref();
-	#			my $which_color = $color_listbox->get_flow_listbox_vacancy_color();
-	#
-	#			_set_flow_color($which_color);
-	#			_set_flow_listbox_color_w($which_color);
-	#	_unset_pre_built_superflow_type();
-	#	_set_user_built_flow_type();
-
-	#	$neutral_flow->set_hash_ref($L_SU_href);
 	$neutral_flow->FileDialog_button($dialog_type_sref);
 
-	#			$L_SU_href->{_flow_color} = $grey_flow->get_flow_color();
+	# $L_SU_href->{_flow_color} = $grey_flow->get_flow_color();
 
 	return ();
 
@@ -1040,6 +1011,12 @@ sub help_menubutton {
 		my $message = $message_director->help_button($item);
 
 	}
+	elsif ( length $install_option_ref
+		and $$install_option_ref eq $help_menubutton_type->{_InstallationGuide} ){
+
+		my $item    = $alias_help_menubutton_label_h->{_InstallationGuide};
+		my $message = $message_director->help_button_pdf($item);		
+	}
 	else {
 		carp("L_SU, can not provide help\n");
 		print("Help button option = $$install_option_ref\n");
