@@ -307,7 +307,7 @@ my $var = {
 	_base_file_name         => 'base_file_name',
 	_clear_text             => '',
 	_color_default          => 'grey',           # first color listbox to select
-	_config_file_format     => '                                                        ',
+	_config_file_format     => '%-35s%1s%-20s',
 	_eight_characters       => '8',
 	_empty_string           => '',
 	_failure                => -1,
@@ -348,9 +348,11 @@ my $var = {
 	_min_clicks4flow_select        => 8,      # fixing leaky param_widget memory
 	_ms2s                          => 0.001,
 	_my_arial                      => "-*-arial-normal-r-*-*-*-120-*-*-*-*-*-*",
-	_my_purple                     => 'MediumPurple1',
+#	_my_purple                     => 'MediumPurple1',
+    _my_purple                     => 'LightSteelBlue',
 	_my_white                      => 'white',
-	_my_yellow                     => 'LightGoldenrod1',
+#	_my_yellow                     => 'LightGoldenrod1',
+    _my_yellow                     => 'white',
 	_my_dark_grey                  => 'DarkGrey',
 	_my_black                      => 'black',
 	_my_light_green                => 'LightGreen',
@@ -369,7 +371,7 @@ my $var = {
 	_one_character                 => '1',
 	_one_pixel                     => '1',
 	_one_pixel_borderwidth         => '1',
-	_program_title                 => 'SeismicUnixGui V0.82.8',
+	_program_title                 => 'SeismicUnixGui V0.82.9',
 	_project_selector_title        => 'Project Selector',
 	_l_suplot_title                => 'L_suplot',
 	_project_selector_title        => 'Project Selector',
